@@ -1,6 +1,8 @@
 use v6;
 
-class PDF::Font::CIDFont {
+use PDF::COS::Tie::Hash;
+role PDF::Font::CIDFont
+    does PDF::COS::Tie::Hash {
 
     use PDF::COS::Tie;
     use PDF::COS::Stream;
