@@ -15,12 +15,7 @@ class PDF::Font::Type3
     has PDF::COS::Name $.Name is entry;                 #| (Required in PDF 1.0; optional otherwise) See Table 5.8 on page 413
     has Numeric @.FontBBox is entry(:required, :len(4));         #| (Required) A rectangle (see Section 3.8.4, “Rectangles”) expressed in the glyph coordinate system, specifying the font bounding box.
     has Numeric @.FontMatrix is entry(:required, :len(6));       #| (Required) An array of six numbers specifying the font matrix, mapping glyph space to text space
-    use PDF::COS::Tie::Hash;
-    use PDF::Content::Graphics;
-    my role CharProc
-        does PDF::Content::Graphics
-        does PDF::COS::Tie::Hash {}
-    has CharProc %.CharProcs is entry(:required);        #| (Required) A dictionary in which each key is a character name and the value associated with that key is a content stream that constructs and paints the glyph for that character.
+    has PDF::COS::Stream %.CharProcs is entry(:required);        #| (Required) A dictionary in which each key is a character name and the value associated with that key is a content stream that constructs and paints the glyph for that character.
 
     use PDF::Encoding;
     my subset NameOrEncoding where PDF::COS::Name | PDF::Encoding;
