@@ -6,8 +6,7 @@ class PDF::Group::Transparency
     is PDF::Group {
     use PDF::COS::Tie;
     use PDF::COS::Name;
-    my subset Name-Transparency of PDF::COS::Name where 'Transparency';
-    has Name-Transparency $.S is entry(:required);
+    has PDF::COS::Name $.S is entry(:required) where 'Transparency';
     my subset NameOrArray where PDF::COS::Name|Array;
     has NameOrArray $.CS is entry(:alias<color-space>); #| (Sometimes required) The group colour space, which is used for the following purposes:
     #| • As the colour space into which colours shall be converted when painted into the group
