@@ -8,8 +8,7 @@ role PDF::Pattern
     use PDF::COS::Tie;
     use PDF::COS::Name;
     #| /Type entry is optional, but should be /Pattern when present
-    my subset Name-Pattern of PDF::COS::Name where 'Pattern';
-    has Name-Pattern $.Type is entry;
+    has PDF::COS::Name $.Type is entry where 'Pattern';
     my subset PatternTypeInt of Int where 1|2;
     has PatternTypeInt $.PatternType is entry(:required);  #| (Required) A code identifying the type of pattern that this dictionary describes; must be 1 for a tiling pattern, or 2 for a shading pattern.
     has Numeric @.Matrix is entry(:len(6));                #| (Optional) An array of six numbers specifying the pattern matrix (see Section 4.6.1, “General Properties of Patterns”). Default value: the identity matrix [ 1 0 0 1 0 0 ].
@@ -20,21 +19,6 @@ role PDF::Pattern
     method type    { 'Pattern' }
     method subtype { PatternNames[ self<PatternType> ] }
 
-    #| see also PDF::Class::Loader
-    method delegate-pattern(Hash :$dict!) {
-
-	use PDF::COS::Util :from-ast;
-	my Int $type-int = from-ast $dict<PatternType>;
-
-	unless $type-int ~~ PatternTypeInt {
-	    note "unknown /PatternType $dict<PatternType> - supported range is 1..7";
-	    return self.WHAT;
-	}
-
-	my $subtype = PatternNames{~$type-int};
-	PDF::COS.loader.find-delegate( 'Pattern', $subtype );
-    }
-
     method cb-init {
 
         for self.^mro {
